function coeff_assorb = Norm866(temp,hum_rel,freq)
% Calcolo del vettore dei coefficienti di assorbimento in dB ogni 100m
% input: temperatura in °C, umidità relativa [0 - 1], vettore delle
% frequenze di centrobanda dei terzi di ottava
% output: vettore dei coefficienti di assorbimento in dB ogni 100m

% normativa SAE 866

h_norm = [0.00, 0.25, 0.50, 0.60, 0.70, 0.80, 0.90, 1.00, 1.10, 1.20,...
    1.30, 1.50, 1.70, 2.00, 2.30, 2.50, 2.80, 3.00, 3.30, 3.60,...
    4.15, 4.45, 4.80, 5.25, 5.70, 6.05, 6.50, 7.00, 10.00];

a_norm = [0.000, 0.315, 0.700, 0.840, 0.930, 0.975, 0.996, 1.000, 0.970,...
    0.900, 0.840, 0.750, 0.670, 0.570, 0.495, 0.450, 0.400, 0.370,...
    0.330, 0.300, 0.260, 0.245, 0.230, 0.220, 0.210, 0.205, 0.200,...
    0.200, 0.200];

if size(freq,2) == 1
    freq = freq';
end
Nfreq = length(freq);

%coefficiente di assorbimento classico
a_class = 10.^(2.05*log10(freq/1000) + (1.1394*1e-3)*temp - 1.916984);
%valuto il coefficiente B
Bb = 1.328924 - (3.179768*1e-2)*temp + (2.173716*1e-4)*temp^2 - (1.7496*1e-6)*temp^3;
%posso ora calcolare l'umidità assoluta
h_a = 10^(log10(hum_rel) - Bb);
%calcolo l'umidità assoluta per il massimo assorbimento molecolare
h_molmax = sqrt(freq/1010);
%valuto l'umidità assoluta h_a normalizzata rispetto all'umidità assoluta per il massimo assorbimento molecolare
h_normalized = h_a./h_molmax;

iii = size(h_norm,2);
a_normalized = zeros(1,Nfreq);
%se il valore che ricavo non è pari a quello tabellato ho bisogno di interpolare
for n = 1:Nfreq
    ind = find(h_norm == h_normalized(n));
    if isempty(ind)
        i1 = find(h_norm < h_normalized(n),1,'last');
        i2 = find(h_norm > h_normalized(n),1,'first');
        a_normalized(n) = a_norm(i1) + (a_norm(i2) - a_norm(i1))*(h_normalized(n) - h_norm(i1))/(h_norm(i2) - h_norm(i1));
    else
        a_normalized(n) = a_norm(ind);
    end
end

%calcolo ora il coefficiente di assorbimento molecolare
a_molmax = 10.^(log10(freq) + (8.42994*1e-3)*temp - 2.755624);
%ho allora che
a_mol = a_molmax.*a_normalized;
% ottengo coefficiente di assorbimeto totale in dB/100m;
coeff_assorb = a_class + a_mol;

end