function [rho_0,T_0,p_0,a_0,M_0,time_app,t_app,r_app,theta_a,phi_a,V,h_pt,T,Aj,Vj,T0j,rhoj,pj,Mj,delta,N,l,delta_T,mdot_off] = landing_fp(distance,altitude,CAS,T,noise_time,Max_T_dry,mdot_proj,NcL_proj,beta_cL,beta_cH,TIT,A_0,A_e,L_conv,L_div,div_angle,T0_e_ab,mdot_ab)


% This function simulates a Landing trajectory composed by 3 flight
% segments,defined by Default Fixed Point Profiles for departure operating 
% mode from the data reported in ANP database.

% IN: Flight path, Thrust --> OUT: - noise measurement data (t,r,theta,phi), 
%                                  - jet noise parameters (Aj1,Vj1,Tj1,rhoj1,pj1,Mj1,delta)
%                                  - fan noise parameters (N,l,delta_T)

%% ******************** Coordinate reference system ***********************

%--> Axis
 
x = -6:15;                          %Distance along runaway centerline [Km]
y = zeros(length(x));              %Distance across runaway centreline [Km]
z = zeros (length(x));              %Altitude [Km] 

% figure (2)

% xlabel('x - [Distance along runaway centerline]','interpreter','latex')
% ylabel('y - [Distance across runaway centreline]','interpreter','latex') 
% zlabel('z - [Altitude]','interpreter','latex')

l = -3:0.1:0;
y2 = zeros(1,length(l));
alt = zeros(1,length(l));
% plot3(l,y2,alt,'LineWidth',2,'Color','b')%Runaway centreline

%%axis([-6 0 -0.5 0.5 0 2])
% xlim([-6 0]);
% ylim([-0.5 0.5]);
% zlim([0 2]);
% xticks([-6 -5 -4 -3 -2 -1 0])
% xticklabels({'-6000','-5000 m','-4000 m','-3000 m','-2000 m','-1000 m','0 m'})
% yticks([-0.5 0 0.5])
% yticklabels({'-500 m','0 m','500 m'})
% zticks([0 0.5])
% zticklabels({'0 m','500 m'})
% 
% set(gca,'FontSize',10)
% set(0,'DefaultAxesFontName', 'Euphemia')
% grid on


%--> Runaway
v = [-3 -0.15; 4.5 -0.15; 4.5 0.15; -3 0.15];
f = [1 2 3 4];

% patch('Faces',f,'Vertices',v,'FaceColor','k','FaceAlpha',.2)


%--> Reference points
hold on

%Approach threshold
y_t = -0.15:0.01:0.15;
x_t = zeros(length(y_t));
z_t = zeros(length(y_t));

plot3(x_t,y_t,z_t,'LineWidth',1.25,'Color','#7E2F8E');

%ILS landing point
y_i = 0;
x_i = 0.3;
z_i = 0;

plot3(x_i,y_i,z_i,'LineWidth',1.25,'Color','#7E2F8E','Marker','|');

%Approach noise measurement point
x_3 = -2;
y_3 = 0;
z_3 = 0;

% plot3(x_3,y_3,z_3,'Color','r','Marker', '*','LineWidth',1.5);

%ILS flight path
x_ILS = -2:0.1:0.3;
y_ILS = zeros(length(x_ILS));
z_ILS = -((x_ILS+2)*0.0543)+0.125;

% plot3(x_ILS,y_ILS,z_ILS,'Color','#7E2F8E','LineWidth',1.5);

%% *************************** Flight path ********************************
    
dt = 0.01; %Time interval for data interpolation

% Trajectory processing
for i = 1: length(distance)-1
if i == 1
    
    % Starting point
    x_air_start(i) = -distance(1)/1000; %[Km]
    y_air_start(i) = 0; 
    z_air_start(i) = altitude(1)/1000; %[Km]
     
else 
    
    x_air_start(i) = x_air_end(i-1);
    y_air_start(i) = y_air_end(i-1);
    z_air_start(i) = z_air_end(i-1);
    
end

% Time [s]
t(i) = abs(distance(i+1)-distance(i))/CAS(i);

% Speed vector [m/s]
v(i) = CAS(i);

if altitude(i) == 0
    v_dir(i) = 0;
else
    v_dir(i) = -atand(altitude(i)/distance(i));
end

vx(i) = v(i)*cosd(v_dir(i));
vy(i) = 0;
vz(i) = v(i)*sind(v_dir(i));

% Ending point 
x_air_end(i) = x_air_start(i)+((vx(i)*t(i)))/1000;
y_air_end(i) = 0;
z_air_end(i) = z_air_start(i)+((vz(i)*t(i)))/1000;

if i == length(distance)-1
    z_air_end(i) = 0;
end

end

% Interpolation
for i = 1:length(distance)-1
    
    np(i) = round(t(i))/dt; %Number of points for interpolation in each flight segment
    
    if i == 1
        
    x_pt(1:np(i)) = linspace(x_air_start(i),x_air_end(i),np(i));
    y_pt(1:np(i)) = linspace(y_air_start(i),y_air_end(i),np(i));
    z_pt(1:np(i)) = linspace(z_air_start(i),z_air_end(i),np(i));
    
    V(1:np(i)) = linspace(v(i),v(i+1),np(i));
    
    else
  
    x_pt((sum(np(1:i-1)))+1:(sum(np(1:i)))) = linspace(x_air_start(i),x_air_end(i),np(i));
    y_pt((sum(np(1:i-1)))+1:(sum(np(1:i)))) = linspace(y_air_start(i),y_air_end(i),np(i));
    z_pt((sum(np(1:i-1)))+1:(sum(np(1:i)))) = linspace(z_air_start(i),z_air_end(i),np(i));
    
    V((sum(np(1:i-1)))+1:(sum(np(1:i)))) = linspace(v(i),v(i+1),np(i));
    
    end
    
end

%Time vector
time_vector = 1:length(x_pt); % 1/100 seconds

%Climb angle vector
gamma = atand(z_pt./x_pt);

%Angle between flight vector and engine inlet axis [deg]
delta = zeros(1,length(time_vector));

% ---> Engine performance 
T_(1:np(1)) = linspace(T(1),T(2),np(1));
for i = 2:length(T)-1
    T_((sum(np(1:i-1)))+1:(sum(np(1:i)))) = linspace(T(i),T(i+1),np(i));
end
T = T_;

ab = 0; % Afterburner OFF

h_pt = round(z_pt); % Altitude [m]
    
    % It is necessary to set h_pt different from zero (indices for atmospheric_model function
    % must be positive or integers)
    
    for i = 1:length(h_pt)
    if h_pt(i) == 0
       h_pt(i) = 1;
    end
    end
  
   for time = 1:time_vector(end)
       
        [rho_0(time),T_0(time),p_0(time),a_0(time),M_0(time)] = atmospheric_model(h_pt(time),V(time));
        
   % Afterburner OFF
   % Hyp: 
   % - critic nozzle: Mt = 1
   
[Aj(time),Vj(time),rhoj(time),T0j(time),pj(time),Mj(time),mdot_off(time),NcL_off(time),delta_T(time)] = TJab_off(ab,T(time),V(time),h_pt(time),T_0(time),p_0(time),M_0(time),Max_T_dry,beta_cL,beta_cH,TIT,A_0,A_e,mdot_proj,L_conv,L_div,div_angle,T0_e_ab,mdot_ab);
   
   if T(time) > Max_T_dry
   N(time) = NcL_proj;
   else
   N(time) = (NcL_off(time))*NcL_proj;
   end
   
   % Accountig for flow distorstion near the ground
    if h_pt(time) == 1
        l(time) = 2;
    else 
        l(time) = 1;
    end
    
   end
   
% --> Noise

%Time interval for approach noise -> indentification of flyover point time
%instant
t_app = find(abs(x_pt - x_3) == min(abs(x_pt - x_3)));


    %-->  Distance and directivity 
    
    %Sideline
    dx_app = abs(x_pt - x_3)*1000; %[m]
    dy_app = abs(y_pt - y_3)*1000; %[m]
    dz_app = abs(z_pt - 0)*1000; %[m]
    r_app = sqrt(dx_app.^2+dy_app.^2+dz_app.^2); % Distance between observer and noise source [m]

    theta_ = asind(dz_app./r_app); %Polar directivity angle [deg]
 
    theta_1 = theta_(1:t_app);
    theta_2 = 180 - theta_(t_app+1:end);
    
    %Polar directivity angle [deg]
    theta_a(1:length(theta_1)) = (theta_1)+gamma(1:t_app);
    theta_a(length(theta_1)+1:(length(theta_1)+length(theta_2))) = (theta_2)+gamma(t_app+1:(length(theta_1)+length(theta_2)));
    
    %Azimuthal directivity angle [deg]
    phi_a(1:length(theta_a))= 0; 
    

%%           %%%%%%%%%%%%%%%%%%%%% GIF image %%%%%%%%%%%%%%%%%%%%
             %   GIF image runs with dt = 0.5 s time interval   %
% h = figure(2);
% xlabel('x','interpreter','latex')
% ylabel('y','interpreter','latex') 
% zlabel('z','interpreter','latex')
% axis tight manual % this ensures that getframe() returns a consistent size
% filename = 'Approach.gif';

dt2 = 0.5/dt;

for time = 1:dt2:time_vector(end)
%       ph = plot3(x_pt(time),y_pt(time),z_pt(time),'p','markerfacecolor','m','markeredgecolor','#7E2F8E','MarkerSize',10);
%       axis([-6 0 -0.5 0.5 0 0.5])
%       daspect([1 1 1])
%       %plot3(x_pt(time),y_pt(time),z_pt(time),'om','MarkerSize',1.5)
%       
%       drawnow 
%       frame = getframe(h); 
%       im = frame2im(frame); 
%       [imind,cm] = rgb2ind(im,256);
%       
%      title({('Approach'),['t = ', num2str(((time-1)*dt)),' s']},'interpreter','latex','FontWeight','bold','FontSize',15);
%      
%       delete(ph)
%       str = ['g' 'r'];

if abs(t_app - time) > ((noise_time/2)/dt)
%     mic = plot3(x_3,y_3,0,'Color',str(2),'Marker', '*','LineWidth',1.5);
else
%     mic = plot3(x_3,y_3,0,'Color',str(1),'Marker', 'o','MarkerSize',3,'LineWidth',1.5);
    
    %Time vector for flyover noise measurement point
    time_app = (t_app-((noise_time/2)/dt)):dt2:((noise_time/2)/dt)+t_app;
end
%       if time == 1 
%           imwrite(imind,cm,filename,'gif', 'Loopcount',inf); 
%       else 
%           imwrite(imind,cm,filename,'gif','WriteMode','append'); 
%       end 
end

% hold on
% plot3(x_pt,y_pt,z_pt,'m')

end
