 function [rho_0,T_0,p_0,a_0,M_0,time_side,t_side,r_side,theta_s,phi_s,time_fly,t_fly,r_fly,theta_f,phi_f,V,h_pt,T,Aj,Vj,T0j,rhoj,pj,Mj,delta,N,l,delta_T,mdot_off] = takeoff_fp(distance,altitude,TAS,T,noise_time,Max_T_dry,mdot_proj,NcL_proj,beta_cL,beta_cH,TIT,A_0,A_e,L_conv,L_div,div_angle,T0_e_ab,mdot_ab)

% This function simulates a Take-Off trajectory composed by 5 flight
% segments,defined by Default Fixed Point Profiles for departure operating 
% mode from the data reported in ANP database.

% IN: Flight path, Thrust --> OUT: - noise measurement data (t,r,theta,phi), 
%                                  - jet noise parameters (Aj1,Vj1,Tj1,rhoj1,pj1,Mj1,delta)
%                                  - fan noise parameters (N,l,delta_T)

%% ********************* Coordinate reference system **********************

%--> Axis
 
x = -4:16;                         %Distance along runaway centerline [Km]
y = zeros(length(x));              %Distance across runaway centreline [Km]
z = zeros (length(x));             %Altitude [Km] 

% figure(2);

xlabel('x - [Distance along runaway centerline]','interpreter','latex')
ylabel('y - [Distance across runaway centreline]','interpreter','latex') 
zlabel('z - [Altitude]','interpreter','latex')
 
x_rw = 0:0.1:4.5;
y_rw = zeros(1,length(x_rw));
z_rw = zeros(1,length(x_rw));
% plot3(x_rw,y_rw,z_rw,'LineWidth',2,'Color','b')%Runaway centreline

% axis([0 15 -0.5 0.5 0 1])
% 
% xticks([0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15])
% xticklabels({'0 m','1000 m','2000 m','3000 m','4000 m','5000 m' ,'6000 m','7000 m','8000 m','9000 m','10000 m','11000 m','12000 m','13000 m','14000 m','15000 m'})
% yticks([-0.5 0 0.5])
% yticklabels({'-500 m','0 m','500 m'})
% zticks([0 0.5 1])
% zticklabels({'0 m','500 m','1000 m'})
% 
% set(gca,'FontSize',10)
% set(0,'DefaultAxesFontName', 'Euphemia')
% grid on

%--> Runaway
v = [-3 -0.10; 4.5 -0.10; 4.5 0.10; -3 0.10];
f = [1 2 3 4];

% patch('Faces',f,'Vertices',v,'FaceColor','k','FaceAlpha',.2)


%--> Reference points
hold on

% Approach threshold
y_t = -0.10:0.01:0.10;
x_t = zeros(length(y_t));
z_t = zeros(length(y_t));

% plot3(x_t,y_t,z_t,'LineWidth',1.25,'Color','#0072BD');

% ILS landing point
y_i = 0;
x_i = 0.3;
z_i = 0;

% plot3(x_i,y_i,z_i,'LineWidth',1.25,'Color','#7E2F8E','Marker','|');

% Start of take-off roll
y_t = -0.10:0.01:0.10;
x_t = ones(length(y_t))*0.1;
z_t = zeros(length(y_t));

% plot3(x_t,y_t,z_t,'LineWidth',1.25,'Color','#D95319');

% Flyover noise measurement point
x_2 = 6.6;
y_2 = 0;
z_2 = 0;

% plot3(x_2,y_2,z_2,'Color','r','Marker', '*','LineWidth',1.5);

% Sideline noise measurement point
x_11 = 3.5;
y_11 = -0.45;
z_11 = 0;

% plot3(x_11,y_11,z_11,'Color','r','Marker', '*','LineWidth',1.5);

x_12 = 3.5;
y_12 = 0.45;
z_12 = 0;

% plot3(x_12,y_12,z_12,'Color','r','Marker', '*','LineWidth',1.5);

%% *************************** Flight path ********************************
    
dt = 0.1; %Time interval for data interpolation

% Trajectory processing
for i = 1: length(distance)-1
if i == 1
    
    % Starting point
    x_air_start(i) = 0.1;
    y_air_start(i) = 0; 
    
else 
    
    x_air_start(i) = x_air_end(i-1);
    y_air_start(i) = y_air_end(i-1);
    
end

% Time [s]
t(i) = abs((distance(i+1)-distance(i)))/TAS(i);

% Speed vector [m/s]
v(i) = TAS(i);

if altitude(i) == 0
    v_dir(i) = 0;
else
    v_dir(i) = atand(altitude(i)/distance(i));
end

vx(i) = v(i)*cosd(v_dir(i));
vy(i) = 0;
vz(i) = v(i)*sind(v_dir(i));

% Ending point 
x_air_end(i) = x_air_start(i)+(vx(i)*t(i))/1000;
y_air_end(i) = 0;
end

% Interpolation
for i = 1:length(distance)-1
    
    np(i) = round(t(i))/dt; %Number of points for interpolation in each flight segment
    
    if i == 1
        
    x_pt(1:np(i)) = linspace(x_air_start(i),x_air_end(i),np(i));
    y_pt(1:np(i)) = linspace(y_air_start(i),y_air_end(i),np(i));
    z_pt(1:np(i)) = linspace(0,altitude(i)/1000,np(i));
    
    else
  
    x_pt((sum(np(1:i-1)))+1:(sum(np(1:i)))) = linspace(x_air_start(i),x_air_end(i),np(i));
    y_pt((sum(np(1:i-1)))+1:(sum(np(1:i)))) = linspace(y_air_start(i),y_air_end(i),np(i));
    z_pt((sum(np(1:i-1)))+1:(sum(np(1:i)))) = linspace(altitude(i)/1000,altitude(i+1)/1000,np(i));

    end
    
end
  
%Time vector
time_vector = 1:length(x_pt); % 1/10 seconds

%Climb angle vector
gamma = atand(z_pt./x_pt);

%Angle between flight vector and engine inlet axis [deg]
delta = zeros(1,length(time_vector));

% ---> Engine performance 
% Interpolation

T_(1:np(1)) = linspace(T(1),T(2),np(1));
for i = 2:length(T)-1
    T_((sum(np(1:i-1)))+1:(sum(np(1:i)))) = linspace(T(i),T(i+1),np(i));
end
T = T_;

V_(1:np(1)) = linspace(TAS(1),TAS(2),np(1));
for i = 2:length(TAS)-1
    V_((sum(np(1:i-1)))+1:(sum(np(1:i)))) = linspace(TAS(i),TAS(i+1),np(i));
end
V = V_;

h_pt = round(z_pt*1000); % Altitude [m]
    
    % It is necessary to set h_pt different from zero (indices for atmospheric_model function
    % must be positive or integers)
    
    for i = 1:length(h_pt)
    if h_pt(i) == 0
       h_pt(i) = 1;
    end
    end
    
for time = 1:time_vector(end)
       
        [rho_0(time),T_0(time),p_0(time),a_0(time),M_0(time)] = atmospheric_model(h_pt(time),V(time));
        
% ---> Engine performance 
    
   [rho_0,T_0,p_0,a_0,M_0] = atmospheric_model(round(h_pt),V);
   
   % Afterburner OFF
   % Hyp: 
   % - critic nozzle: Mt = 1
   
   if T(time) > Max_T_dry
       ab(time)= 1;
   else 
       ab(time) = 0;
   end
   
%    if h_pt(time) > 250
%        conf = 0;
%    else 
%        conf = 1;
%    end
  
[Aj(time),Vj(time),rhoj(time),T0j(time),pj(time),Mj(time),mdot_off(time),NcL_off(time),delta_T(time)] = TJab_off(ab(time),T(time),V(time),h_pt(time),T_0(time),p_0(time),M_0(time),Max_T_dry,beta_cL,beta_cH,TIT,A_0,A_e,mdot_proj,L_conv,L_div,div_angle,T0_e_ab,mdot_ab);
   
   if T(time) > Max_T_dry
   N(time) = NcL_proj;
   else
   N(time) = (NcL_off(time))*NcL_proj;
   end
    
    if h_pt(time) == 1
        l(time) = 2;
    else 
        l(time) = 1;
    end
    
end
   
% --> Noise

%Time interval for sideline noise -> indentification of flyover point time
%instant
t_side = find(abs(x_pt - x_11) == min(abs(x_pt - x_11)));

%Time interval for flyover noise -> identification of flyover point time
%instant
t_fly = find(abs(x_pt - x_2) == min(abs(x_pt - x_2)));

    %-->  Distance and directivity 
    
    %Sideline
    dx_side = abs(x_pt - x_11)*1000; %[m]
    dy_side = abs(y_pt - y_11)*1000; %[m]
    dz_side = abs(z_pt - 0)*1000; %[m]
    r_side = sqrt(dx_side.^2+dy_side.^2+dz_side.^2); % Distance between observer and noise source [m]
    r_side_p = sqrt(dx_side.^2+dz_side.^2); %D istance between observer and noise source on x-z plane[m]
    
    theta_ = asind(dz_side./r_side_p); %Polar directivity angle [deg]
 
    theta_1 = theta_(1:t_side);
    theta_2 = 180 - theta_(t_side+1:end);
    
    %Polar directivity angle [deg]
    theta_s(1:length(theta_1)) = (theta_1)+gamma(1:t_side);
    theta_s(length(theta_1)+1:(length(theta_1)+length(theta_2))) = (theta_2)+gamma(t_side+1:(length(theta_1)+length(theta_2)));
    
    %Azimuthal directivity angle [deg]
    phi_s(1:length(theta_s))= 90; 
    
    %Flyover
    dx_fly = abs(x_pt - x_2)*1000; %[m]
    dy_fly = abs(y_pt - y_2)*1000; %[m]
    dz_fly = abs(z_pt - 0)*1000; %[m]
    r_fly = sqrt(dx_fly.^2+dy_fly.^2+dz_fly.^2); %Distance between observer and noise source [m]
    
    theta_= asind(dz_fly./r_fly); %Polar directivity angle [rad]
    
    theta_1f = theta_(1:t_fly);
    theta_2f = 180 - theta_(t_fly+1:end);
    
    
    %Polar directivity angle [deg]
    theta_f(1:length(theta_1f)) = (theta_1f)+gamma(1:t_fly);
    theta_f(length(theta_1f)+1:(length(theta_1f)+length(theta_2f))) = (theta_2f)+gamma(t_fly+1:length(theta_1f)+length(theta_2f));
    
    %Azimuthal directivity angle [deg]
    phi_f(1:length(theta_f))= 0;
    
    %%           %%%%%%%%%%%%%%%%%%%%% GIF image %%%%%%%%%%%%%%%%%%%%
             %   GIF image runs with dt = 0.5 s time interval   %
% h = figure(2);
% xlabel('x','interpreter','latex')
% ylabel('y','interpreter','latex') 
% zlabel('z','interpreter','latex')
% axis tight manual % this ensures that getframe() returns a consistent size
% filename = 'Departure.gif';

dt2 = 0.5/dt;

for time = 1:dt2:time_vector(end)
%       ph = plot3(x_pt(time),y_pt(time),z_pt(time),'p','markerfacecolor','m','markeredgecolor','#7E2F8E','MarkerSize',10);
%       axis([0 15 -0.5 0.5 0 1])
%       daspect([1 1 1])
%       %plot3(x_pt(time),y_pt(time),z_pt(time),'om','MarkerSize',1.5)
      
%       drawnow 
%       frame = getframe(h); 
%       im = frame2im(frame); 
%       [imind,cm] = rgb2ind(im,256);
      
%      title({('Departure'),['t = ', num2str(((time-1)*dt*0.5)),' s']},'interpreter','latex','FontWeight','bold','FontSize',15);
%      
%       delete(ph)
%       str = ['g' 'r'];
      
if abs(t_side - time) > ((noise_time/2)/dt)
%     mic11 = plot3(x_11,y_11,0,'Color',str(2),'Marker', '*','LineWidth',1.5);
%     mic12 = plot3(x_12,y_12,0,'Color',str(2),'Marker', '*','LineWidth',1.5);
else
%     mic11 = plot3(x_11,y_11,0,'Color',str(1),'Marker', 'o','MarkerSize',3,'LineWidth',1.5);
%     mic12 = plot3(x_12,y_12,0,'Color',str(1),'Marker', 'o','MarkerSize',3,'LineWidth',1.5);
    
    % Time vector for sideline noise measurement point
    time_side = (t_side-((noise_time/2)/dt)):dt2:((noise_time/2)/dt)+t_side;
end

if abs(t_fly - time) > ((noise_time/2)/dt)
%     mic2 = plot3(x_2,y_2,0,'Color',str(2),'Marker', '*','LineWidth',1.5);
else
%     mic2 = plot3(x_2,y_2,0,'Color',str(1),'Marker', 'o','MarkerSize',3,'LineWidth',1.5);
    
    %Time vector for flyover noise measurement point
    time_fly = (t_fly-((noise_time/2)/dt)):dt2:((noise_time/2)/dt)+t_fly;
end
%       if time == 1 
%           imwrite(imind,cm,filename,'gif', 'Loopcount',inf); 
%       else 
%           imwrite(imind,cm,filename,'gif','WriteMode','append'); 
%       end 
end
 
% hold on
% plot3(x_pt,y_pt,z_pt,'m')

 end
